SanitizedTransaction

Struct SanitizedTransaction 

pub struct SanitizedTransaction { /* private fields */ }
Sanitized transaction and the hash of its message

Implementations

Source

impl SanitizedTransaction

pub fn try_new( tx: SanitizedVersionedTransaction, message_hash: Hash, is_simple_vote_tx: bool, address_loader: impl AddressLoader, reserved_account_keys: &HashSet<Address>, ) -> Result<SanitizedTransaction, TransactionError>

Create a sanitized transaction from a sanitized versioned transaction. If the input transaction uses address tables, attempt to lookup the address for each table index.

pub fn try_create( tx: VersionedTransaction, message_hash: impl Into<MessageHash>, is_simple_vote_tx: Option<bool>, address_loader: impl AddressLoader, reserved_account_keys: &HashSet<Address>, ) -> Result<SanitizedTransaction, TransactionError>

Create a sanitized transaction from an un-sanitized versioned transaction. If the input transaction uses address tables, attempt to lookup the address for each table index.

pub fn try_from_legacy_transaction( tx: Transaction, reserved_account_keys: &HashSet<Address>, ) -> Result<SanitizedTransaction, TransactionError>

Create a sanitized transaction from a legacy transaction

pub fn from_transaction_for_tests(tx: Transaction) -> SanitizedTransaction

Create a sanitized transaction from a legacy transaction. Used for tests only.

pub fn try_new_from_fields( message: SanitizedMessage, message_hash: Hash, is_simple_vote_tx: bool, signatures: Vec<Signature>, ) -> Result<SanitizedTransaction, TransactionError>

Create a sanitized transaction from fields. Performs only basic signature sanitization.

pub fn signature(&self) -> &Signature

Return the first signature for this transaction.

Notes:

Sanitized transactions must have at least one signature because the number of signatures must be greater than or equal to the message header value num_required_signatures which must be greater than 0 itself.

pub fn signatures(&self) -> &[Signature]

Return the list of signatures for this transaction

pub fn message(&self) -> &SanitizedMessage

Return the signed message

pub fn message_hash(&self) -> &Hash

Return the hash of the signed message

pub fn is_simple_vote_transaction(&self) -> bool

Returns true if this transaction is a simple vote

pub fn to_versioned_transaction(&self) -> VersionedTransaction

Convert this sanitized transaction into a versioned transaction for recording in the ledger.

pub fn get_account_locks( &self, tx_account_lock_limit: usize, ) -> Result<TransactionAccountLocks<'_>, TransactionError>

Validate and return the account keys locked by this transaction

pub fn get_account_locks_unchecked(&self) -> TransactionAccountLocks<'_>

Return the list of accounts that must be locked during processing this transaction.

pub fn get_loaded_addresses(&self) -> LoadedAddresses

Return the list of addresses loaded from on-chain address lookup tables

pub fn get_durable_nonce(&self) -> Option<&Address>

If the transaction uses a durable nonce, return the pubkey of the nonce account

pub fn verify(&self) -> Result<(), TransactionError>

Verify the transaction signatures

pub fn validate_account_locks( message: &SanitizedMessage, tx_account_lock_limit: usize, ) -> Result<(), TransactionError>

Validate a transaction message against locked accounts