#[repr(C)]pub struct PriceUpdateV2 {
pub write_authority: Pubkey,
pub verification_level: VerificationLevel,
pub price_message: PriceFeedMessage,
pub posted_slot: u64,
}Expand description
Pyth PriceUpdateV2 account structure (Pyth Solana Receiver format)
Fields
verification_level: VerificationLevelprice_message: PriceFeedMessageposted_slot: u64Trait Implementations
Sourceimpl BorshDeserialize for PriceUpdateV2
impl BorshDeserialize for PriceUpdateV2
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for PriceUpdateV2
impl BorshSerialize for PriceUpdateV2
Sourceimpl Clone for PriceUpdateV2
impl Clone for PriceUpdateV2
Sourcefn clone(&self) -> PriceUpdateV2
fn clone(&self) -> PriceUpdateV2
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for PriceUpdateV2